diff --git a/macosx/English.lproj/MainMenu.nib/info.nib b/macosx/English.lproj/MainMenu.nib/info.nib
index 91184950e..415d22dd4 100644
--- a/macosx/English.lproj/MainMenu.nib/info.nib
+++ b/macosx/English.lproj/MainMenu.nib/info.nib
@@ -7,7 +7,7 @@
IBEditorPositions
1041
- 344 478 208 130 0 0 1152 842
+ 439 418 208 130 0 0 1152 842
1480
366 546 420 63 0 0 1152 842
1603
@@ -31,9 +31,9 @@
3
IBOpenObjects
- 1041
- 21
+ 1480
29
+ 21
IBSystem Version
8J135
diff --git a/macosx/Controller.m b/macosx/Controller.m
index 97fdfd81d..976c9d82f 100644
--- a/macosx/Controller.m
+++ b/macosx/Controller.m
@@ -1590,8 +1590,8 @@ static void sleepCallBack(void * controller, io_service_t y, natural_t messageTy
[self setWindowSizeToFit];
- //resize for larger min height
- if (!makeSmall && contentSize.height < contentMinSize.height)
+ //resize for larger min height if not set to auto size
+ if (!makeSmall && ![fDefaults boolForKey: @"AutoSize"] && contentSize.height < contentMinSize.height)
{
NSRect frame = [fWindow frame];
float heightChange = contentMinSize.height - contentSize.height;
diff --git a/macosx/English.lproj/MainMenu.nib/keyedobjects.nib b/macosx/English.lproj/MainMenu.nib/keyedobjects.nib
index 2ca77f867..c19183d3c 100644
Binary files a/macosx/English.lproj/MainMenu.nib/keyedobjects.nib and b/macosx/English.lproj/MainMenu.nib/keyedobjects.nib differ
diff --git a/macosx/Transmission Help/gfx/TransIcon.gif b/macosx/Transmission Help/gfx/TransIcon.gif
index 75137b77f..48be78681 100644
Binary files a/macosx/Transmission Help/gfx/TransIcon.gif and b/macosx/Transmission Help/gfx/TransIcon.gif differ